<?php namespace prlbr\mathjaxcdn;

/* Copyright 2017-2021 Martin Janecke <aneamal@prlbr.de>
 *
*  This math module for Aneamal is licensed under the MIT License:
*  https://opensource.org/licenses/MIT
*
*  MathJax is licensed under the Apache License 2.0:
*  https://github.com/mathjax/MathJax/blob/master/LICENSE
*/

/* The function prepares a mathematical expression for client-side parsing by
*  MathJax. When the function is called for the first time, the function also
*  adds the code that loads the MathJax software from a content delivery network
*  (CDN) and some configuration settings.
*/
return function (array $_) {

	// for backwards compatibility with Aneamal 27
	$_['math'] = $_['math'] ?? $_[0];
	$_['kind'] = $_['kind'] ?? ($_[1] === 'text'? 'string': 'block');

	// MathJax only needs to be included once, which is checked by looking for
	// a static variable $included
	static $included = false;

	if ($included):
		$mathjax = '';
	else:
		// the class '_mathjax_ignore' is added to the body, which makes MathJax
		// ignore everything except regions with the class '_mathjax' that we
		// add later to math content
		$preps = "<script>document.body.classList.add('_mathjax_ignore');</script>";
		
		// MathJax is loaded from the CDN recommended by MathJax here:
		// https://docs.mathjax.org/en/latest/web/start.html
		// MathJax itself shut down a CDN that was recommended in the past.
		// There is no guarantee that the new one will not be shut down, too.
		// You can host MathJax on your own server to be in full control.
		// See: https://docs.mathjax.org/en/latest/web/hosting.html
		$source = 'https://cdn.jsdelivr.net/npm/mathjax@3.2.0/es5/tex-chtml.js';

		// set up MathJax
		$options = '<script>window.MathJax = {options: {enableMenu: false, ignoreHtmlClass: "_mathjax_ignore", processHtmlClass: "_mathjax"}, tex: {displayMath: [["$$","$$"]], inlineMath: [["$","$"]], processEnvironments: false, processRefs: false, autoload: {color: [], colorv2: ["color"]}, packages: {"[+]": ["noerrors"]}}, loader: {load: ["[tex]/noerrors"]}};</script>';

		// return the options and including code; this order is significant
		$mathjax = $preps . $options . "<script src='$source' id='MathJax-script'></script>";

		$included = true;
	endif;

	$code = htmlspecialchars (trim ($_['math']), ENT_SUBSTITUTE, 'UTF-8');
	if ($_['kind'] === 'string'):
		return $mathjax . "<span class='_mathjax'>$" . $code . '$</span>';
	else:
		return $mathjax . "<div class='_mathjax'>$$" . $code . '$$</div>';
	endif;
};

// Last changed: 2021M05 | MathJax 3.2.0